API
===

The API (application programming interface) is described here with the
documentation of the Solver class and its methods.

.. currentmodule:: saenopy.solver

.. autoclass:: Solver
   :members:

